==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cave/dialogs_de.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Diese Fledermaus muss unglaublich stark sein.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Oh ja.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Diese rote Kreatur ist ein wenig merkwürdig.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Kann sein. Ich denke aber, wir werden sie brauchen.")


dialogId("jes-v-uzke", "font_big", "It`s too narrow for me. You have to do it on your own down there.")
dialogStr("Das ist zu eng für mich. Du musst das da unten alleine erledigen.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Dieser weiße Fisch ist ein schreckliches Hindernis.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Fisch? Ich dachte, das ist nur ein Stein.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Ich denke, wir sollten woanders nach dem Gral suchen...")


dialogId("jes-m-deprese", "font_small", "Don`t be depressive. We will solve this in no time.")
dialogStr("Jetzt sei nicht depressiv. Das werden wir ruckzuck gelöst haben.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Ich bin da nicht so sicher.")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Siehts du? Du bist hier.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Was ist das für ein schillerndes Monster?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("Das ist ja scheußlich.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("Das ist eine Beleidigung der Natur.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("Das ist der glitzernde Hammerkopf.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("Das ist der glänzende Widerling.")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("Das ist der Politikerfisch.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Diese Fledermaus ist seltsam.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Diese Fledermaus ist ziemlich phlegmatisch.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Das ist eine ausgestopfte Fledermaus.")


dialogId("jes-v-netopyr1", "font_big", "It`s a sculpture of bat.")
dialogStr("Das ist eine Fledermaus-Skulptur.")


dialogId("jes-m-netopyr2", "font_small", "It`s a stalagmite shaped as a bat.")
dialogStr("Das ist ein Tropfstein in der Form einer Fledermaus.")


dialogId("jes-v-netopyr2", "font_big", "It`s a plain stalagmite.")
dialogStr("Das ist ein einfacher Tropfstein.")


dialogId("jes-m-netopyr3", "font_small", "It`s just an ordinary piece of rock.")
dialogStr("Das ist nur ein gewöhnlicher Stein.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster`.")
dialogStr("Ich denke, du wirst dieses \"Monster\" brauchen.")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination`.")
dialogStr("Ich denke, du wirst deine Abneigung gegen dieses \"Monster\" überwinden müssen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cave/dialogs_de.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Diese Fledermaus muss unglaublich stark sein.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Oh ja.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Diese rote Kreatur ist ein wenig merkwürdig.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Kann sein. Ich denke aber, wir werden sie brauchen.")


dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")
dialogStr("Das ist zu eng für mich. Du musst das da unten alleine erledigen.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Dieser weiße Fisch ist ein schreckliches Hindernis.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Fisch? Ich dachte, das ist nur ein Stein.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Ich denke, wir sollten woanders nach dem Gral suchen...")


dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")
dialogStr("Jetzt sei nicht depressiv. Das werden wir ruckzuck gelöst haben.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Ich bin da nicht so sicher.")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Siehts du? Du bist hier.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Was ist das für ein schillerndes Monster?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("Das ist ja scheußlich.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("Das ist eine Beleidigung der Natur.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("Das ist der glitzernde Hammerkopf.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("Das ist der glänzende Widerling.")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("Das ist der Politikerfisch.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Diese Fledermaus ist seltsam.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Diese Fledermaus ist ziemlich phlegmatisch.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Das ist eine ausgestopfte Fledermaus.")


dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")
dialogStr("Das ist eine Fledermaus-Skulptur.")


dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")
dialogStr("Das ist ein Tropfstein in der Form einer Fledermaus.")


dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")
dialogStr("Das ist ein einfacher Tropfstein.")


dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")
dialogStr("Das ist nur ein gewöhnlicher Stein.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")
dialogStr("Ich denke, du wirst dieses \"Monster\" brauchen.")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
dialogStr("Ich denke, du wirst deine Abneigung gegen dieses \"Monster\" überwinden müssen.")
